==> sflphone_1.3.0.orig.tar.gz: sflphone-1.3.0/kde/src/lib/dbus/videomanager.h <==
/****************************************************************************
 *   Copyright (C) 2012-2014 by Savoir-Faire Linux                          *
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com> *
 *                                                                          *
 *   This library is free software; you can redistribute it and/or          *
 *   modify it under the terms of the GNU Lesser General Public             *
 *   License as published by the Free Software Foundation; either           *
 *   version 2.1 of the License, or (at your option) any later version.     *
 *                                                                          *
 *   This library is distributed in the hope that it will be useful,        *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 *   Lesser General Public License for more details.                        *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef VIDEOMANAGER_H
#define VIDEOMANAGER_H

#include "video_dbus_interface.h"
#include "../typedefs.h"

namespace DBus {

   /**
   * @author Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com>
   */
   class LIB_EXPORT VideoManager
   {

   private:
      static VideoInterface* interface;

   public:
      static VideoInterface& instance();

   };

}

#endif

==> sflphone_1.4.1.orig.tar.gz: sflphone-1.4.1/kde/src/lib/dbus/videomanager.h <==
/****************************************************************************
 *   Copyright (C) 2012-2014 by Savoir-Faire Linux                          *
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com> *
 *                                                                          *
 *   This library is free software; you can redistribute it and/or          *
 *   modify it under the terms of the GNU Lesser General Public             *
 *   License as published by the Free Software Foundation; either           *
 *   version 2.1 of the License, or (at your option) any later version.     *
 *                                                                          *
 *   This library is distributed in the hope that it will be useful,        *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 *   Lesser General Public License for more details.                        *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef VIDEOMANAGER_H
#define VIDEOMANAGER_H

#include "video_dbus_interface.h"
#include "../typedefs.h"

namespace DBus {

   /**
   * @author Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com>
   */
   class LIB_EXPORT VideoManager
   {

   private:
      static VideoManagerInterface* interface;

   public:
      static VideoManagerInterface& instance();

   };

}

#endif
